Inter RAO Energosbyt Python
===========================
Библиотека для работы с ЕЛК ЖКХ компании Интер РАО.

Библиотека подвергается частым изменениям, так как находится в стадии постоянной разработки.